@@ -1,19 +1,16 @@
-//! This example showcases the uart module.
+//! This example showcases the uart::v2 module.
 
 #![no_std]
 #![no_main]
 
 use cortex_m::asm;
-#[cfg(not(feature = "use_semihosting"))]
 use panic_halt as _;
-#[cfg(feature = "use_semihosting")]
-use panic_semihosting as _;
 
 use bsp::hal;
 use bsp::pac;
-use feather_m0 as bsp;
+use feather_m4 as bsp;
 
-use bsp::{entry, periph_alias, pin_alias};
+use bsp::entry;
 use hal::clock::GenericClockController;
 use hal::dmac::{DmaController, PriorityLevel};
 use hal::prelude::*;
@@ -25,35 +22,34 @@ fn main() -> ! {
     let mut peripherals = Peripherals::take().unwrap();
     let mut clocks = GenericClockController::with_internal_32kosc(
         peripherals.GCLK,
-        &mut peripherals.PM,
-        &mut peripherals.SYSCTRL,
+        &mut peripherals.MCLK,
+        &mut peripherals.OSC32KCTRL,
+        &mut peripherals.OSCCTRL,
         &mut peripherals.NVMCTRL,
     );
 
-    let mut pm = peripherals.PM;
+    let mut mclk = peripherals.MCLK;
     let dmac = peripherals.DMAC;
     let pins = bsp::Pins::new(peripherals.PORT);
 
+    // Take RX and TX pins
+    let (rx_pin, tx_pin) = (pins.d0, pins.d1);
+
     // Setup DMA channels for later use
-    let mut dmac = DmaController::init(dmac, &mut pm);
+    let mut dmac = DmaController::init(dmac, &mut peripherals.PM);
     let channels = dmac.split();
 
     let chan0 = channels.0.init(PriorityLevel::LVL0);
     let chan1 = channels.1.init(PriorityLevel::LVL0);
 
-    // Take peripheral and pins
-    let uart_sercom = periph_alias!(peripherals.uart_sercom);
-    let uart_rx = pin_alias!(pins.uart_rx);
-    let uart_tx = pin_alias!(pins.uart_tx);
-
     // Setup UART peripheral
     let uart = bsp::uart(
         &mut clocks,
         9600.hz(),
-        uart_sercom,
-        &mut pm,
-        uart_rx,
-        uart_tx,
+        peripherals.SERCOM5,
+        &mut mclk,
+        rx_pin,
+        tx_pin,
     );
 
     // Split uart in rx + tx halves
